courses : Activities — amici1

# `courses` : Activities

See also `lino_xl.lib.courses`.

## Models

## Actors

- Activity states : (no docstring)

- Enrolment states : (no docstring)

- Course layouts : (no docstring)

- Timetable Slots : (no docstring)

- Topics : (no docstring)

- Activity lines : (no docstring)

- Activity lines : (no docstring)

- Calendar entries : Show calendar entries of activities led by this teacher

- Activities : (no docstring)

- Activities : (no docstring)

- Activities : (no docstring)

- Activities : (no docstring)

- My Activities : (no docstring)

- My courses given : (no docstring)

- Activities : (no docstring)

- Activities : (no docstring)

- Activities : (no docstring)

- Draft activities : (no docstring)

- Current activities : (no docstring)

- Inactive courses : (no docstring)

- Closed courses : (no docstring)

- Enrolments : (no docstring)

- Enrolments : (no docstring)

- Pending requested enrolments : (no docstring)

- Pending confirmed enrolments : (no docstring)

- Enrolments in Activities : (no docstring)

- Enrolments : (no docstring)

- Enrolments using this option : (no docstring)

- Status Report : Gives an overview about what’s up today .